@@ -10,9 +10,9 @@
 #include <fcntl.h>
 #include <string.h>
 #include <linux/kd.h>
-#include "kdmapop.h"
 
 #include "libcommon.h"
+#include "kfont.h"
 
 int main(int argc, char *argv[])
 {
@@ -26,7 +26,13 @@ int main(int argc, char *argv[])
 		console = argv[2];
 
 	if ((fd = getfd(console)) < 0)
-		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console"));
+		kbd_error(EXIT_FAILURE, 0, _("Couldn't get a file descriptor referring to the console."));
 
-	return loadunimap(fd, NULL, NULL);
+	int ret;
+	struct kfont_context *ctx;
+
+	if ((ret = kfont_init(get_progname(), &ctx)) < 0)
+		return -ret;
+
+	return kfont_put_unicodemap(ctx, fd, NULL, NULL);
 }
